@@ -1,16 +1,13 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import unicode_literals
 from email.encoders import encode_base64
 
 import unittest2 as unittest
 from mox3.mox import MoxTestBase, IsA
-from gevent import Timeout
 from gevent.socket import socket, error as socket_error
 from gevent.event import AsyncResult
 
+from slimta.util import pycompat
 from slimta.util.deque import BlockingDeque
-from slimta.smtp import ConnectionLost, SmtpError
+from slimta.smtp import ConnectionLost
 from slimta.relay import TransientRelayError, PermanentRelayError
 from slimta.relay.smtp.lmtpclient import LmtpRelayClient
 from slimta.envelope import Envelope
@@ -34,7 +31,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.sendall(b'LHLO test\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'420 Goodbye\r\n')
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._ehlo()
         with self.assertRaises(TransientRelayError):
@@ -56,7 +53,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         result.set({'rcpt@example.com': None})
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -73,7 +70,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.sendall(b'.\r\nRSET\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'550 Yikes\r\n250 Ok\r\n')
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -94,7 +91,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.sendall(b'RSET\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -111,7 +108,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'550 Yikes\r\n250 Ok\r\n')
         result.set_exception(IsA(PermanentRelayError))
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -128,7 +125,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.sendall(b'RSET\r\n')
         self.sock.recv(IsA(int)).AndRaise(ConnectionLost)
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._ehlo()
         with self.assertRaises(ConnectionLost):
@@ -142,11 +139,14 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\nRCPT TO:<rcpt@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n250 Ok\r\n354 Go ahead\r\n')
-        self.sock.sendall(b'From: sender@example.com\r\nContent-Transfer-Encoding: base64\r\n\r\ndGVzdCB0ZXN0IIENCg==\n\r\n.\r\n')
+        if pycompat.PY3:
+            self.sock.sendall(b'From: sender@example.com\r\nContent-Transfer-Encoding: base64\r\n\r\ndGVzdCB0ZXN0IIEK\r\n.\r\n')
+        else:
+            self.sock.sendall(b'From: sender@example.com\r\nContent-Transfer-Encoding: base64\r\n\r\ndGVzdCB0ZXN0IIENCg==\r\n.\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         result.set({'rcpt@example.com': None})
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test', binary_encoder=encode_base64)
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test', binary_encoder=encode_base64)
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -161,7 +161,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         result.set_exception(IsA(PermanentRelayError))
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -171,7 +171,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._disconnect()
 
@@ -180,7 +180,7 @@ class TestLmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndRaise(socket_error(None, None))
         self.sock.close()
         self.mox.ReplayAll()
-        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='test')
+        client = LmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
         client._connect()
         client._disconnect()
 
