@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 import email.utils
 
 import unittest2 as unittest
@@ -20,23 +19,23 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.io = IO(self.sock)
         self.make_msgid = email.utils.make_msgid = lambda: '<test@example.com>'
 
-    def test_str(self):
+    def test_bytes(self):
         auth = AuthSession(SASLAuth(), self.io)
         self.assertEqual('CRAM-MD5 LOGIN PLAIN', str(auth))
 
     def test_invalid_mechanism(self):
         auth = AuthSession(SASLAuth(), self.io)
         with self.assertRaises(InvalidMechanismError):
-            auth.server_attempt('TEST')
+            auth.server_attempt(b'TEST')
         with self.assertRaises(InvalidMechanismError):
-            auth.server_attempt('B@D')
+            auth.server_attempt(b'B@D')
 
     def test_plain_noarg(self):
         self.sock.sendall(b'334 \r\n')
         self.sock.recv(IsA(int)).AndReturn(b'dGVzdHppZAB0ZXN0dXNlcgB0ZXN0cGFzc3dvcmQ=\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        result = auth.server_attempt('PLAIN')
+        result = auth.server_attempt(b'PLAIN')
         self.assertEqual(u'testuser', result.authcid)
         self.assertEqual(u'testpassword', result.secret)
         self.assertEqual(u'testzid', result.authzid)
@@ -44,7 +43,7 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
     def test_plain(self):
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        result = auth.server_attempt('PLAIN dGVzdHppZAB0ZXN0dXNlcgB0ZXN0cGFzc3dvcmQ=')
+        result = auth.server_attempt(b'PLAIN dGVzdHppZAB0ZXN0dXNlcgB0ZXN0cGFzc3dvcmQ=')
         self.assertEqual(u'testuser', result.authcid)
         self.assertEqual(u'testpassword', result.secret)
         self.assertEqual(u'testzid', result.authzid)
@@ -55,9 +54,9 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
         with self.assertRaises(AuthenticationCanceled):
-            auth.server_attempt('PLAIN')
+            auth.server_attempt(b'PLAIN')
         with self.assertRaises(AuthenticationCanceled):
-            auth.server_attempt('PLAIN *')
+            auth.server_attempt(b'PLAIN *')
 
     def test_login_noarg(self):
         self.sock.sendall(b'334 VXNlcm5hbWU6\r\n')
@@ -66,7 +65,7 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'dGVzdHBhc3N3b3Jk\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        result = auth.server_attempt('LOGIN')
+        result = auth.server_attempt(b'LOGIN')
         self.assertEqual(u'testuser', result.authcid)
         self.assertEqual(u'testpassword', result.secret)
         self.assertEqual(None, result.authzid)
@@ -76,7 +75,7 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'dGVzdHBhc3N3b3Jk\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        result = auth.server_attempt('LOGIN dGVzdHVzZXI=')
+        result = auth.server_attempt(b'LOGIN dGVzdHVzZXI=')
         self.assertEqual(u'testuser', result.authcid)
         self.assertEqual(u'testpassword', result.secret)
         self.assertEqual(None, result.authzid)
@@ -86,7 +85,7 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'dGVzdHVzZXIgNDkzMzA1OGU2ZjgyOTRkZTE0NDJkMTYxOTI3ZGI5NDQ=\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        result = auth.server_attempt('CRAM-MD5')
+        result = auth.server_attempt(b'CRAM-MD5')
         self.assertEqual(u'testuser', result.authcid)
         self.assertTrue(result.check_secret(u'testpassword'))
         self.assertFalse(result.check_secret(u'testwrong'))
@@ -98,14 +97,15 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
         with self.assertRaises(ServerAuthError):
-            auth.server_attempt('CRAM-MD5')
+            auth.server_attempt(b'CRAM-MD5')
 
     def test_client_bad_mech(self):
         self.sock.sendall(b'AUTH LOGIN\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'535 Nope!\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        reply = auth.client_attempt('test@example.com', 'asdf', None, 'LOGIN')
+        reply = auth.client_attempt(u'test@example.com', u'asdf',
+                                    None, b'LOGIN')
         self.assertEqual('535', reply.code)
         self.assertEqual('5.0.0 Nope!', reply.message)
 
@@ -114,7 +114,8 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        reply = auth.client_attempt('test@example.com', 'asdf', 'jkl', 'PLAIN')
+        reply = auth.client_attempt(u'test@example.com', u'asdf', u'jkl',
+                                    b'PLAIN')
         self.assertEqual('235', reply.code)
         self.assertEqual('2.0.0 Ok', reply.message)
 
@@ -127,7 +128,8 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        reply = auth.client_attempt('test@example.com', 'asdf', None, 'LOGIN')
+        reply = auth.client_attempt(u'test@example.com', u'asdf',
+                                    None, b'LOGIN')
         self.assertEqual('235', reply.code)
         self.assertEqual('2.0.0 Ok', reply.message)
 
@@ -138,7 +140,8 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'535 Nope!\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        reply = auth.client_attempt('test@example.com', 'asdf', None, 'LOGIN')
+        reply = auth.client_attempt(u'test@example.com', u'asdf',
+                                    None, b'LOGIN')
         self.assertEqual('535', reply.code)
         self.assertEqual('5.0.0 Nope!', reply.message)
 
@@ -149,7 +152,8 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        reply = auth.client_attempt('test@example.com', 'asdf', None, 'CRAM-MD5')
+        reply = auth.client_attempt(u'test@example.com', u'asdf',
+                                    None, b'CRAM-MD5')
         self.assertEqual('235', reply.code)
         self.assertEqual('2.0.0 Ok', reply.message)
 
@@ -158,7 +162,8 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        reply = auth.client_attempt('test@example.com', 'asdf', None, 'XOAUTH2')
+        reply = auth.client_attempt(u'test@example.com', u'asdf',
+                                    None, b'XOAUTH2')
         self.assertEqual('235', reply.code)
         self.assertEqual('2.0.0 Ok', reply.message)
 
@@ -169,7 +174,8 @@ class TestSmtpAuth(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'535 Nope!\r\n')
         self.mox.ReplayAll()
         auth = AuthSession(SASLAuth(), self.io)
-        reply = auth.client_attempt('test@example.com', 'asdf', None, 'XOAUTH2')
+        reply = auth.client_attempt(u'test@example.com', u'asdf',
+                                    None, b'XOAUTH2')
         self.assertEqual('535', reply.code)
         self.assertEqual('5.0.0 Nope!', reply.message)
 
